// Description: This file contains some of the reusable metadata.

const debug = false;

if (debug) {
    console.log("config.js loaded");
}

const midiConfig = {
    "midi_channel": {
        "label": "MIDI Channel",
        "menu": {
            "1": "0",
            "2": "1",
            "3": "2",
            "4": "3",
            "5": "4",
            "6": "5",
            "7": "6",
            "8": "7",
            "9": "8",
            "10": "9",
            "11": "10",
            "12": "11",
            "13": "12",
            "14": "13",
            "15": "14",
            "16": "15"
        }
    },
    "midi_7bit": {
        "number": {
            "min": 0,
            "max": 127
        }
    },
    "midi_14bit": {
        "number": {
            "min": 0,
            "max": 16383,
            "mid": 8192
        }
    }
};

const codeDisplayConfig = {
    "json_root": {
        "label": "Root Level JSON code (General Settings)",
        "rows": 6,
        "container": "pre"
    },
    "keyboard_assignments": {
        "label": "keyboard_assignments JSON code",
        "rows": 10,
        "container": "pre"
    },
    "pages": {
        "label": "pages JSON code",
        "rows": 10,
        "container": "pre"
    },
    "pedal_assignments": {
        "label": "pedal_assignments JSON code",
        "rows": 10,
        "container": "pre"
    },
    "touchstrip_assignments": {
        "label": "touchstrip_assignments JSON code",
        "rows": 10,
        "container": "pre"
    },
    "wheel_assignments": {
        "label": "wheel_assignments JSON code",
        "rows": 10,
        "container": "pre"
    }
};

const uiConfig = {
    "level_1_sections": {
        "copy_parts_section": {
            "summary": "Copy sections from another template file (.kmt)"
        },
        "general_settings_section": {
            "summary": "General Settings"
        },
        "pages_section": {
            "summary": "Button and Knob Pages"
        },
        "code_section": {
            "summary": "Code"
        }
    },
    "remove_image": {
        "type": "button",
        "text": "0x128465",  // unicode trash can
        "title": "Remove Image"
    },
    "image_file": {
        "type": "file",
        "label": "Import Template Image File (webp, png, jpeg) (1280x212): ",
        "onchange": "importImageFile()",
        "width": 1280,
        "height": 212,
        "accept": "image/webp, image/png, image/jpeg"
    },
    "template_file": {
        "type": "file",
        "label": "Select a Template File (.kmt) to work on: ",
        "accept": ".kmt"
    },
    "parts_selection": {
        "type": "multicheckbox",
        "label": "Step 1: Select the sections to be imported into the current template",
        "options": {
            "Keyboard Assignments": "keyboard_assignments",
            "Button and Knob Pages": "pages",
            "Pedal Assignments": "pedal_assignments",
            "Touchstrip Assignments": "touchstrip_assignments",
            "Wheel Assignments": "wheel_assignments"
        }
    },
    "template_file_2": {
        "type": "file",
        "label": "Step 2: Copy the above selections from this template .kmt file:",
        "accept": ".kmt"
    }
};

const pedalConfig = {
    "PedalAssign1": "Assign 1",
    "PedalAssign2": "Assign 2",
    "PedalExpression": "Expression",
    "PedalSustain": "Sustain"
};

const inputItemConfig = {
    "template_name": {
        "type": "text",
        "label": "Template Name",
        "title": "Between 1 and 32 characters",
        "min_length": 1,
        "max_length": 32
    },
    "hide_template_name": {
        "type": "checkbox",
        "label": "Hide Template Name",
        "title": "This only matters when there actually is an image for this template"
    },
    "color": {
        "type": "select",
        "label": "Default LED Color",
        "options": {
            "Hardware Default": "",
            "White": "White",
            "Red": "Red", 
            "Orange": "Orange", 
            "Light Orange": "Light Orange", 
            "Warm Yellow": "Warm Yellow", 
            "Yellow": "Yellow", 
            "Lime": "Lime", 
            "Green": "Green", 
            "Mint": "Mint", 
            "Cyan": "Cyan", 
            "Turquoise": "Turquoise", 
            "Blue": "Blue", 
            "Plum": "Plum", 
            "Violet": "Violet", 
            "Purple": "Purple", 
            "Magenta": "Magenta", 
            "Fuchsia": "Fuchsia"
       }
    },
    "button_color": {
        "type": "select",
        "label": "",
        "options": {
            "Hardware Default": "",
            "White": "White",
            "Red": "Red", 
            "Orange": "Orange", 
            "Light Orange": "Light Orange", 
            "Warm Yellow": "Warm Yellow", 
            "Yellow": "Yellow", 
            "Lime": "Lime", 
            "Green": "Green", 
            "Mint": "Mint", 
            "Cyan": "Cyan", 
            "Turquoise": "Turquoise", 
            "Blue": "Blue", 
            "Plum": "Plum", 
            "Violet": "Violet", 
            "Purple": "Purple", 
            "Magenta": "Magenta", 
            "Fuchsia": "Fuchsia"
       }
    },
    "knob_display_mode": {
        "type": "select",
        "label": "",
        "options": {
            "Integer": "unipolar_int",
            "Bipolar Int": "bipolar_int",
            "%": "unipolar_percent", 
            "Bipolar %": "bipolar_percent", 
            "Bipolar 50": "bipolar_percent_50", 
            "GM Vol dB": "gm_volume_db"
       }
    },
    "image_data": {
        "type": "image",
        "label": "Template Image",
        "fig_caption": "Template Image",
        "background_style": "background-color: black;"
    },
    "midi_output_preference": {
        "type": "select",
        "label": "MIDI Output Port",
        "options": {
            "Use Hardware Global Setting": null,
            "USB port only": "usb_priority",
            "MIDI port only": "din_priority",
            "Dual: MIDI & USB": "dual" 
       }
    },
    "pageRowLabels": [
        "Button LED Color", 
        "Button Label", 
        " ", 
        "Knob Label", 
        "Knob Display Mode"
    ],
    "pedal_mode": {
        "type": "radio",
        "label": "Mode",
        "options": {
            "Off": "off",
            "Continuous": "pedal_continuous_configuration",
            "Switch": "pedal_switch_configuration"
        }
    },
    "pedal_continuous_invert": {
        "type": "checkbox",
        "label": "Invert Min/Max"
    },
    "pedal_continuous_swap_tip_ring": {
        "type": "checkbox",
        "label": "Swap Tip/Ring"
    },
    "pedal_switch_invert": {
        "type": "checkbox",
        "label": "Invert On/Off"
    },
    "keyboard_assignments_priority": {
        "type": "radio",
        "label": "Priority",
        "options": {
            "Plugin": "plugin",
            "Keyzone": "keyzone"
        }
    },
    "velocity_curve": {
        "type": "select",
        "label": "Velocity Curve",
        "options": {
            "Default": "",
            "Soft 1": "soft1",
            "Soft 2": "soft2",
            "Soft 3": "soft3",
            "Linear": "linear",
            "Hard 1": "hard1",
            "Hard 2": "hard2",
            "Hard 3": "hard3"
        }
    },
    "button_label": {
        "type": "text",
        "label": "",
        "min_length": 1,
        "max_length": 16
    },
    "knob_label": {
        "type": "text",
        "label": "",
        "min_length": 1,
        "max_length": 16
    }
};

if (debug) console.log(inputItemConfig);
