
function domAddButton(containerId, domConfig, onClick, onClickParameter) {
        
    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";
    newContainer.classList.add("wrapper");

    const newButton = document.createElement("button");
    newButton.id = containerId;
    // newButton.value = String.fromCodePoint(domConfig.text.substring(2));
    // newButton.textContent = String.fromCodePoint(domConfig.text.substring(2));
    if (domConfig.text.startsWith("0x")) {
        // Unicode
        newButton.textContent = String.fromCodePoint(domConfig.text.substring(2), 16);
    } else {
        newButton.textContent = domConfig.text;
    }
    newButton.title = domConfig.title;
    newButton.addEventListener("click", () => { onClick(onClickParameter) });

    newContainer.appendChild(newButton);

    return newContainer;
}

function domAddInputFile(containerId, domConfig, onChange, onChangeParameter) {

    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";
    newContainer.classList.add("wrapper");

    const newInput = document.createElement("input");
    newInput.type = "file";
    newInput.id = containerId;
    newInput.accept = domConfig.accept;
    newInput.addEventListener("change", () => { onChange(onChangeParameter) });

    const newLabel = document.createElement("label");
    newLabel.textContent = domConfig.label;
    newLabel.htmlFor = newInput.id;

    newContainer.appendChild(newLabel);
    newContainer.appendChild(newInput);

    return newContainer;

}

function domAddImage(containerId, domConfig, selectedImage, onLoad) {

    const newContainer = document.createElement("figure");
    newContainer.id = containerId + "_figure";

    const newCaption = document.createElement("figcaption");
    newCaption.id = containerId + "_figcaption";
    newCaption.textContent = domConfig.fig_caption;

    const newBackground = document.createElement("div");
    newBackground.id = containerId + "_img_background";
    newBackground.style = domConfig.background_style;

    const newImage = document.createElement("img");
    newImage.id = containerId;
    newImage.src = selectedImage;
    newImage.addEventListener("load", () => { onLoad(newImage) });
 
    newContainer.appendChild(newBackground);
    newBackground.appendChild(newImage);
    newContainer.appendChild(newCaption);

    return newContainer;
}

function domAddInputCheckbox(containerId, domConfig, selectedValue) {
        
    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";
    newContainer.classList.add("wrapper");

    const newInput = document.createElement("input");
    newInput.type = "checkbox";
    newInput.id = containerId;
    newInput.checked = selectedValue;

    const newLabel = document.createElement("label");
    newLabel.textContent = domConfig.label;
    newLabel.htmlFor = newInput.id;

    newContainer.appendChild(newInput);
    newContainer.appendChild(newLabel);

    return newContainer;
}

function domAddMultiCheckbox(containerId, domConfig, selectedValues) {

    const newContainer = document.createElement("fieldset");
    newContainer.id = containerId + "_fieldset";
    // newContainer.classList.add("wrapper");

    const newLegend = document.createElement("legend");
    newLegend.textContent = domConfig.label;
    newContainer.appendChild(newLegend);

    // console.log("domConfig.options: ", domConfig);
    for (const [label, value] of Object.entries(uiConfig[containerId].options)) {
        const newWrapper = document.createElement("span");
        newWrapper.id = containerId + "_" + value + "_wrapper";
        newWrapper.classList.add("wrapper");
        newWrapper.classList.add("nowrap");
        const newInput = document.createElement("input");
        newInput.type = "checkbox";
        newInput.id = containerId + "_" + value;
        const newLabel = document.createElement("label");
        newLabel.textContent = label;
        newLabel.htmlFor = newInput.id;
    
        newWrapper.appendChild(newInput);
        newWrapper.appendChild(newLabel);
        newContainer.appendChild(newWrapper);

    }

    return newContainer;

}

function domAddInputRadio(containerId, domConfig, selectedValue) {
    const newContainer = document.createElement("fieldset");
    newContainer.id = containerId + "_fieldset";
    // newContainer.classList.add("wrapper");

    const newLegend = document.createElement("legend");
    newLegend.textContent = domConfig.label;
    newContainer.appendChild(newLegend);

    for (const [label, value] of Object.entries(domConfig.options)) {
        const newInput = document.createElement("input");
        newInput.type = "radio";
        // newInput.classList.add("radio");

        newInput.name = containerId + "_radio";

        newInput.id = containerId + "_" + value;
        newInput.value = value;
        if (value == selectedValue) {
            newInput.checked = true;
        }

        const newLabel = document.createElement("label");
        newLabel.textContent = label;
        newLabel.htmlFor = newInput.id;

        newContainer.appendChild(newInput);
        newContainer.appendChild(newLabel);
    }
    return newContainer;
}

function domAddSelect (containerId, domConfig, selectedValue) {

    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";
    newContainer.classList.add("wrapper");

    const newSelect = document.createElement("select");
    newSelect.id = containerId;

    const newLabel = document.createElement("label");
    newLabel.textContent = domConfig.label;
    newLabel.htmlFor = newSelect.id;

    newContainer.appendChild(newLabel);
    newContainer.appendChild(newSelect);

    for (const [label, value] of Object.entries(domConfig.options)) {
        const newOption = document.createElement("option");
        newOption.value = value;
        newOption.textContent = label;
        if (newOption.value == selectedValue) {
            newOption.selected = true;
        }
        newSelect.appendChild(newOption);
    }
    return newContainer;
}

function domAddInputText(containerId, domConfig, selectedValue) {

    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";
    newContainer.classList.add("wrapper");

    const newInput = document.createElement("input");
    newInput.type = "text";
    newInput.id = containerId;
    newInput.minLength = domConfig.min_length;
    newInput.maxLength = domConfig.max_length;
    newInput.size = domConfig.max_length;
    newInput.style = `width: ${domConfig.max_length + 2}ch; text-align: center;`
    newInput.value = selectedValue;

    const newLabel = document.createElement("label");
    newLabel.textContent = domConfig.label;
    newLabel.htmlFor = newInput.id;

    newContainer.appendChild(newLabel);
    newContainer.appendChild(newInput);

    return newContainer;
}

function domAddTextArea(containerId, domConfig, selectedValue) {
    const newContainer = document.createElement("span");
    newContainer.id = containerId + "_wrapper";

    const newTextArea = document.createElement("textarea");
    newTextArea.id = containerId;
    newTextArea.rows = domConfig.rows;
    newTextArea.readOnly = true;
    newTextArea.value = selectedValue;

    const newLabel = document.createElement("label");
    newLabel.textContent = domConfig.label;
    newLabel.htmlFor = newTextArea.id;

    newContainer.appendChild(newLabel);

    if (domConfig.hasOwnProperty("container")) {
        const subContainer = document.createElement(domConfig.container);
        newContainer.appendChild(subContainer);
        subContainer.appendChild(newTextArea);
    } else {
        newContainer.appendChild(newTextArea);
    }

    return newContainer;
}
