function generateTemplatePages() {
    let numberOfPages = document.getElementById("hwPages").value;
    let buttonsMidiChannel = document.getElementById("hwButtonsMidiChannel").value;
    let buttonColors = new Array();
    for ( let hwButtonNumber = 1; hwButtonNumber <= 8; hwButtonNumber++ ) {
        buttonColors[hwButtonNumber - 1] = document.getElementById(`button${hwButtonNumber}_color`).value;
        // console.log();
    }
    let knobsMidiChannel = document.getElementById("hwKnobsMidiChannel").value;
    let knobsBehaviourMode = document.getElementById("hwKnobsBehaviourMode").value;
    let knobsDisplayMode = document.getElementById("hwKnobsDisplayMode").value;

    let pages = [];
    for ( let pageNumber = 0; pageNumber < numberOfPages; pageNumber++ ) {
        

        pages[pageNumber] = {
            "buttons": makeButtons(pageNumber, buttonsMidiChannel, buttonColors),
            "knobs": makeKnobs(pageNumber, knobsMidiChannel, knobsDisplayMode, knobsBehaviourMode)
        };


    }

    document.getElementById("pages").value = JSON.stringify(pages, null, 4);

}

function makeButtons (pageNumber, midiChannel, colors) {

    let buttons = [];
    for ( let buttonNumber = 0; buttonNumber < 8; buttonNumber++ ) {
        let ccNumber = pageNumber * 8 + buttonNumber;
        let label = "CC " + ccNumber;
        buttons[buttonNumber] = {
            "color": colors[buttonNumber],
            "custom_label": true,
            "label": label,
            "mapping": {
                "assignment": {
                    "cc": {
                        "midi_cc_number": ccNumber,
                        "midi_channel": Number(midiChannel - 1)
                    }
                },
                "behaviour": {
                    "toggle": {
                        "off": 0,
                        "on": 127
                    }
                }
            }
        }
    }
    return buttons;

}

function makeKnobs (pageNumber, midiChannel, displayMode, behaviourMode) {

    let knobs = [];

    let knobsBehaviour = "";
    if ( behaviourMode == "absolute") {
        knobsBehaviour = {
            "absolute": {
                "max": 127,
                "min": 0
            }
        }
    }
    else if ( behaviourMode == "relative") {
        knobsBehaviour = {
            "relative": {
                "step": 1
            }
        }
    }
    else if ( behaviourMode == "relative_offset") {
        knobsBehaviour = {
            "relative_offset": {
                "step": 1
            }
        }
    }

    for ( let knobNumber = 0; knobNumber < 8; knobNumber++ ) {
        let ccNumber = pageNumber * 8 + knobNumber;
        let label = "CC " + ccNumber;
        knobs[knobNumber] = {
            "custom_label": false,
            "display_mode": displayMode,
            "label": label,
            "mapping": {
                "assignment": {
                    "cc": {
                        "midi_cc_number": ccNumber,
                        "midi_channel": Number(midiChannel - 1)
                    }
                },
                "behaviour": knobsBehaviour
            }
        }
    }

    return knobs;
     
}